Module http

Module http 

HTTP interface related request/response types.

Structs

HttpModemBatteryLevelResponse
Battery status information from the modem.
HttpModemNetworkOperatorResponse
Network operator information from the modem.
HttpModemNetworkStatusResponse
Network registration status of the modem.
HttpModemSignalStrengthResponse
Signal strength information from the modem.
HttpPaginationOptions
HTTP pagination options allow for lazy reading of large sets of data, for example if thousands of messages have been sent and received from a phone number it would be impractical to request all of them at the same time, instead it can be read in shorter pages using limit+offset. This is applied at the server level when requesting data from database.
HttpSmsDeviceInfoResponse
Formatted device info response, with each value packed into a proper optional response.
HttpSmsSendResponse
Response returned after sending an SMS message.
LatestNumberFriendlyNamePair
Used in latest-numbers return value, as a number and friendly name.