Module sms

Module sms 

Generic types that apply to both HTTP and Websocket interfaces.

Structs

SmsDeliveryReport
A received or stored delivery report.
SmsIncomingMessage
An incoming message from the Modem.
SmsMessage
Represents a stored SMS message from the database.
SmsMultipartHeader
The sms message multipart header.
SmsOutgoingMessage
The outgoing SMS message to be sent to a target number.
SmsPartialDeliveryReport
A partial message delivery report, as it comes from the modem.

Enums

SmsDeliveryReportStatusCategory
A general category of status message delivery status reports.