pub struct SmsOutgoingMessage {
pub phone_number: String,
pub content: String,
pub flash: bool,
pub validity_period: Option<u8>,
pub timeout: Option<u32>,
}Expand description
A partial outgoing message.
Fields
phone_number: StringTarget phone number.
content: StringMessage text content.
flash: boolShould the message be sent as a Class 0 flash delivery.
validity_period: Option<u8>An optional validity period used by the SMC, default 24hr.
timeout: Option<u32>A timeout to use for sending an SMS message.
Implementations
Sourceimpl SmsOutgoingMessage
impl SmsOutgoingMessage
Sourcepub fn get_validity_period(&self) -> u8
pub fn get_validity_period(&self) -> u8
Get the message sending validity period, either as set or default.